==> haskell-vty-unix-0.2.0.0-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-unix
version:              0.2.0.0
visibility:           public
id:                   vty-unix-0.2.0.0-3pUjP8PBRK1JuELGan9n6
key:                  vty-unix-0.2.0.0-3pUjP8PBRK1JuELGan9n6
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  135b0e1a580f62fc58e99cbd9b455934
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-unix-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-unix-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-unix-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.2.0.0-3pUjP8PBRK1JuELGan9n6
includes:             cbits/gwinsz.h
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3wnAa360A0589gqzb0DfpQ
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw mtl-2.3.1
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.6 transformers-0.6.1.0
    unix-2.8.4.0 utf8-string-1.0.2-4PcjKdTUnsVIUZCxTUoFbK
    vector-0.13.2.0-6vtrErFI1tV1Z02auPMCSS
    vty-6.2-pyIUADYsRh7VRKvKzTwjQ

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-unix-0.2.0.0-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-unix
version:              0.2.0.0
visibility:           public
id:                   vty-unix-0.2.0.0-K1qySh95uTQukeSSo5X15
key:                  vty-unix-0.2.0.0-K1qySh95uTQukeSSo5X15
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  70fb112355824f097ace2b74b6ab79dd
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-unix-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-unix-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-unix-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.2.0.0-K1qySh95uTQukeSSo5X15
includes:             cbits/gwinsz.h
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-2e1Y8rZXOgP89l4uRglwJl
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw mtl-2.3.1
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.6 transformers-0.6.1.0
    unix-2.8.4.0 utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-3Co1wNPhccp6XnsJEn8cXR
    vty-6.2-GJSVM62QIvN9hRMOjtPpjh

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
